@@ -1,7 +1,8 @@
 package SVN::Hooks::AllowLogChange;
 
-use warnings;
 use strict;
+use warnings;
+use Carp;
 use SVN::Hooks;
 
 use Exporter qw/import/;
@@ -54,45 +55,42 @@ Regexp.
 
 =cut
 
-sub ALLOW_LOG_CHANGE {
-    my $conf = $SVN::Hooks::Confs->{$HOOK};
+my @Valid_Users;
 
-    foreach my $who (@_) {
-	if (! ref $who or ref $who eq 'Regexp') {
-	    push @{$conf->{users}}, $who;
+sub ALLOW_LOG_CHANGE {
+    my @args = @_;
+
+    foreach my $who (@args) {
+	if (not ref $who or ref $who eq 'Regexp') {
+	    push @Valid_Users, $who;
 	}
 	else {
-	    die "$HOOK: invalid argument '$who'\n";
+	    croak "$HOOK: invalid argument '$who'\n";
 	}
     }
 
-    $conf->{'pre-revprop-change'} = \&pre_revprop_change;
+    PRE_REVPROP_CHANGE(\&pre_revprop_change);
 
-    1;
+    return 1;
 }
 
-$SVN::Hooks::Inits{$HOOK} = sub {
-    return { users => [] };
-};
-
 sub pre_revprop_change {
-    my ($self, $rev, $author, $propname, $action) = @_;
+    my ($svnlook, $rev, $author, $propname, $action) = @_;
 
     $propname eq 'svn:log'
-	or die "$HOOK: the revision property $propname cannot be changed.\n";
+	or croak "$HOOK: the revision property $propname cannot be changed.\n";
 
     $action eq 'M'
-	or die "$HOOK: a revision log can only be modified, not added or deleted.\n";
+	or croak "$HOOK: a revision log can only be modified, not added or deleted.\n";
 
     # If no users are specified, anyone can do it.
-    return unless @{$self->{users}};
+    return unless @Valid_Users;
 
-    for my $user (@{$self->{users}}) {
-	return if ! ref $user and $author eq $user or $author =~ $user;
+    for my $user (@Valid_Users) {
+	return if not ref $user and $author eq $user or $author =~ $user;
     }
 
-    die "$HOOK: you are not allowed to change a revision log.\n";
-
+    croak "$HOOK: you are not allowed to change a revision log.\n";
 }
 
 =head1 AUTHOR
