@@ -18,9 +18,10 @@ SVN::Hooks::Generic - Implement generic checks for all Subversion hooks.
 =head1 SYNOPSIS
 
 This SVN::Hooks plugin allows you to easily write generic checks for
-all Subversion standard hooks.
+all Subversion standard hooks. It's deprecated. You should use the
+SVN::Hooks hook defining exported directives instead.
 
-It's configured by the following directive.
+This module is configured by the following directive.
 
 =head2 GENERIC(HOOK => FUNCTION, HOOK => [FUNCTIONS], ...)
 
@@ -43,21 +44,21 @@ The function signatures are the following:
 
 =item post-commit(SVN::Look)
 
-=item post-lock(repository-path, username)
+=item post-lock(repos-path, username)
 
 =item post-revprop-change(SVN::Look, username, property-name, action)
 
-=item post-unlock(repository-path, username)
+=item post-unlock(repos-path, username)
 
 =item pre-commit(SVN::Look)
 
-=item pre-lock(repository-path, username, comment, steal-lock-flag)
+=item pre-lock(repos-path, path, username, comment, steal-lock-flag)
 
 =item pre-revprop-change(SVN::Look, username, property-name, action)
 
-=item pre-unlock(repository-path, username, lock-token, break-unlock-flag)
+=item pre-unlock(repos-path, path, username, lock-token, break-unlock-flag)
 
-=item start-commit(repository-path, username, capabilities)
+=item start-commit(repos-path, username, capabilities)
 
 =back
 
@@ -69,13 +70,13 @@ performing the Subversion action which triggered the hook.
 The sketch below shows how this directive could be used.
 
 	sub my_start_commit {
-	    my ($repo, $username, $capabilities) = @_;
-	    // ...
+	    my ($repo_path, $username, $capabilities) = @_;
+	    # ...
 	}
 
 	sub my_pre_commit {
 	    my ($svnlook) = @_;
-	    // ...
+	    # ...
 	}
 
 	GENERIC(
@@ -93,8 +94,6 @@ sub GENERIC {
 
     my %args = @args;
 
-    my $conf = $SVN::Hooks::Confs->{$HOOK};
-
     while (my ($hook, $functions) = each %args) {
 	$hook =~ /(?:(?:pre|post)-(?:commit|lock|revprop-change|unlock)|start-commit)/
 	    or die "$HOOK: invalid hook name ($hook)";
@@ -108,17 +107,13 @@ sub GENERIC {
 	foreach my $foo (@$functions) {
 	    ref $foo and ref $foo eq 'CODE'
 		or die "$HOOK: hook '$hook' should be mapped to CODE-refs.\n";
-	    push @{$conf->{$hook}}, $foo;
+	    $SVN::Hooks::Hooks{$hook}{$foo} ||= sub { $foo->(@_); };
 	}
     }
 
     return 1;
 }
 
-$SVN::Hooks::Inits{$HOOK} = sub {
-    return {};
-};
-
 =head1 AUTHOR
 
 Gustavo Chaves, C<< <gnustavo@cpan.org> >>
